==> nextcloud-13.0.1.tgz: nextcloud/apps/workflowengine/l10n/sk.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saved" : "Uložené",
    "Saving failed:" : "Ukladanie neúspešné:",
    "File MIME type" : "MIME typ súboru",
    "is" : "je",
    "is not" : "nie je",
    "matches" : "súhlasí",
    "does not match" : "nesúhlasí",
    "Example: {placeholder}" : "Napríklad: {placeholder}",
    "File size (upload)" : "Veľkosť súboru (upload)",
    "less" : "menej",
    "less or equals" : "menej alebo rovné",
    "greater or equals" : "viac alebo rovné",
    "greater" : "viac",
    "File system tag" : "Štítok súborového systému",
    "is tagged with" : "je označený",
    "is not tagged with" : "nie je označený",
    "Select tag…" : "Vyber štítok...",
    "Request remote address" : "Vyžiadať vzdialenú adresu",
    "matches IPv4" : "súhlasí s IPv4",
    "does not match IPv4" : "nesúhlasí s IPv4",
    "matches IPv6" : "súhlasí s IPv6",
    "does not match IPv6" : "nesúhlasí s IPv6",
    "Request time" : "Čas požiadavky",
    "between" : "medzi",
    "not between" : "nie je medzi",
    "Start" : "Začiatok",
    "End" : "Koniec",
    "Select timezone…" : "Vybrať časové pásmo...",
    "Request URL" : "Vyžiadať URL",
    "Predefined URLs" : "Preddefinované URL",
    "Files WebDAV" : "WebDAV súbory",
    "Request user agent" : "User agent požiadavky",
    "Sync clients" : "Synchronizovať klientov",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Desktopový klient",
    "User group membership" : "Členstvo v skupine používateľov",
    "is member of" : "Je členom",
    "is not member of" : "Nie je členom",
    "The given operator is invalid" : "Zadaný operátor je neplatný",
    "The given regular expression is invalid" : "Zadaný regulárny výraz je neplatný",
    "The given file size is invalid" : "Zadaná veľkosť súboru je neplatná",
    "The given tag id is invalid" : "Zadaný identifikátor štítku je neplatný",
    "The given IP range is invalid" : "Zadaný rozsah IP je neplatný",
    "The given IP range is not valid for IPv4" : "Zadaný IP rozsah nie je platný pre IPv4",
    "The given IP range is not valid for IPv6" : "Zadaný IP rozsah nie je platný pre IPv6",
    "The given time span is invalid" : "Zadané časové rozpätie nie je platné",
    "The given start time is invalid" : "Zadaný čas začatia nie je platný",
    "The given end time is invalid" : "Zadaný čas ukončenia nie je platný",
    "The given group does not exist" : "Zadaná skupina neexistuje",
    "Check %s is invalid or does not exist" : "Kontrola %s je neplatná alebo neexistuje",
    "Operation #%s does not exist" : "Operácia #%s neexistuje",
    "Operation %s does not exist" : "Operácia %s neexistuje",
    "Operation %s is invalid" : "Operácia #%s nie je platná",
    "Check %s does not exist" : "Kontrola %s neexistuje",
    "Check %s is invalid" : "Kontrola %s je neplatná",
    "Check #%s does not exist" : "Kontrola #%s neexistuje",
    "Workflow" : "Systém práce",
    "Files workflow engine" : "Typ spôsobu práce súborov",
    "Open documentation" : "Otvoriť dokumentáciu",
    "Add rule group" : "Pridať skupinu pravidiel",
    "Short rule description" : "Zobraziť popis pravidla",
    "Add rule" : "Pridať pravidlo",
    "Reset" : "Vynulovať",
    "Save" : "Uložiť",
    "Saving…" : "Ukladá sa...",
    "Loading…" : "Načítava sa..."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-14.0.1.tgz: nextcloud/apps/workflowengine/l10n/sk.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Unable to retrieve the group list" : "Nie je možné načítať zoznam skupín",
    "Saved" : "Uložené",
    "Saving failed:" : "Ukladanie neúspešné:",
    "File MIME type" : "MIME typ súboru",
    "is" : "je",
    "is not" : "nie je",
    "matches" : "súhlasí",
    "does not match" : "nesúhlasí",
    "Example: {placeholder}" : "Napríklad: {placeholder}",
    "File size (upload)" : "Veľkosť súboru (upload)",
    "less" : "menej",
    "less or equals" : "menej alebo rovné",
    "greater or equals" : "viac alebo rovné",
    "greater" : "viac",
    "File system tag" : "Štítok súborového systému",
    "is tagged with" : "je označený",
    "is not tagged with" : "nie je označený",
    "Select tag…" : "Vyber štítok...",
    "Request remote address" : "Vyžiadať vzdialenú adresu",
    "matches IPv4" : "súhlasí s IPv4",
    "does not match IPv4" : "nesúhlasí s IPv4",
    "matches IPv6" : "súhlasí s IPv6",
    "does not match IPv6" : "nesúhlasí s IPv6",
    "Request time" : "Čas požiadavky",
    "between" : "medzi",
    "not between" : "nie je medzi",
    "Start" : "Začiatok",
    "End" : "Koniec",
    "Select timezone…" : "Vybrať časové pásmo...",
    "Request URL" : "Vyžiadať URL",
    "Predefined URLs" : "Preddefinované URL",
    "Files WebDAV" : "WebDAV súbory",
    "Request user agent" : "User agent požiadavky",
    "Sync clients" : "Synchronizovať klientov",
    "Android client" : "Android klient",
    "iOS client" : "iOS klient",
    "Desktop client" : "Desktopový klient",
    "User group membership" : "Členstvo v skupine používateľov",
    "is member of" : "Je členom",
    "is not member of" : "Nie je členom",
    "The given operator is invalid" : "Zadaný operátor je neplatný",
    "The given regular expression is invalid" : "Zadaný regulárny výraz je neplatný",
    "The given file size is invalid" : "Zadaná veľkosť súboru je neplatná",
    "The given tag id is invalid" : "Zadaný identifikátor štítku je neplatný",
    "The given IP range is invalid" : "Zadaný rozsah IP je neplatný",
    "The given IP range is not valid for IPv4" : "Zadaný IP rozsah nie je platný pre IPv4",
    "The given IP range is not valid for IPv6" : "Zadaný IP rozsah nie je platný pre IPv6",
    "The given time span is invalid" : "Zadané časové rozpätie nie je platné",
    "The given start time is invalid" : "Zadaný čas začatia nie je platný",
    "The given end time is invalid" : "Zadaný čas ukončenia nie je platný",
    "The given group does not exist" : "Zadaná skupina neexistuje",
    "Check %s is invalid or does not exist" : "Kontrola %s je neplatná alebo neexistuje",
    "Operation #%s does not exist" : "Operácia #%s neexistuje",
    "Operation %s does not exist" : "Operácia %s neexistuje",
    "Operation %s is invalid" : "Operácia #%s nie je platná",
    "Check %s does not exist" : "Kontrola %s neexistuje",
    "Check %s is invalid" : "Kontrola %s je neplatná",
    "Check #%s does not exist" : "Kontrola #%s neexistuje",
    "Workflow" : "Systém práce",
    "Files workflow engine" : "Typ spôsobu práce súborov",
    "Open documentation" : "Otvoriť dokumentáciu",
    "Add rule group" : "Pridať skupinu pravidiel",
    "Short rule description" : "Zobraziť popis pravidla",
    "Add rule" : "Pridať pravidlo",
    "Reset" : "Vynulovať",
    "Save" : "Uložiť",
    "Saving…" : "Ukladá sa...",
    "Loading…" : "Načítava sa..."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
